====
m209
====
A historically accurate M-209 library written in Python 3
---------------------------------------------------------

- **Author:** Brian Neal <bgneal@gmail.com>
- **Version:** 1.0.0
- **Date:** November 6, 2025
- **Home Page:** https://github.com/gremmie/m209
- **License:** MIT License (see LICENSE.txt)
- **Documentation:** https://m209.readthedocs.org
- **Support:** https://github.com/gremmie/m209/issues

The `M-209`_ is a mechanical cipher machine used by the US military during World
War II and up to the Korean War. The M-209 is also known as the CSP-1500 by
the US Navy. The M-209 is an example of a Hagelin device, a family of
mechanical cipher machines created by Swedish inventor `Boris Hagelin`_.

This project is a Python 3 library and command-line utility for encrypting and
decrypting text by simulating the operation of an actual M-209 device.

Please see the documentation_ for library usage, tutorials and
references.


.. _M-209: http://en.wikipedia.org/wiki/M-209
.. _Boris Hagelin: http://en.wikipedia.org/wiki/Boris_Hagelin
.. _documentation: https://m209.readthedocs.org
